@@ -367,11 +367,10 @@ class CountryField(CharField):
     get_choices = lazy(get_choices, list)
 
     def formfield(self, **kwargs):
-        argname = 'choices_form_class'
-        if argname not in kwargs:
-            kwargs[argname] = (
-                LazyTypedMultipleChoiceField
-                if self.multiple else LazyTypedChoiceField)
+        kwargs.setdefault(
+            'choices_form_class',
+            LazyTypedMultipleChoiceField
+            if self.multiple else LazyTypedChoiceField)
         if 'coerce' not in kwargs:
             kwargs['coerce'] = super(CountryField, self).to_python
         field = super(CharField, self).formfield(**kwargs)
@@ -382,6 +381,8 @@ class CountryField(CharField):
             return super(CountryField, self).to_python(value)
         if not value:
             return value
+        if isinstance(value, basestring):
+            value = value.split(',')
         output = []
         for item in value:
             output.append(super(CountryField, self).to_python(item))
@@ -412,6 +413,13 @@ class CountryField(CharField):
             raise exceptions.ValidationError(
                 self.error_messages['blank'], code='blank')
 
+    def value_to_string(self, obj):
+        """
+        Ensure data is serialized correctly.
+        """
+        value = self.value_from_object(obj)
+        return self.get_prep_value(value)
+
 
 FieldListFilter.register(
     lambda f: isinstance(f, CountryField), filters.CountryFilter)
