@@ -109,7 +109,7 @@ IOC_TO_ISO = {
     'LBR': 'LR',
     'LCA': 'LC',
     'LES': 'LS',
-    'LIB': 'LB',
+    'LBN': 'LB',
     'LIE': 'LI',
     'LTU': 'LT',
     'LUX': 'LU',
@@ -161,11 +161,11 @@ IOC_TO_ISO = {
     'SAM': 'WS',
     'SEN': 'SN',
     'SEY': 'SC',
-    'SIN': 'SG',
     'SKN': 'KN',
     'SLE': 'SL',
     'SLO': 'SI',
     'SMR': 'SM',
+    'SNG': 'SG',
     'SOL': 'SB',
     'SOM': 'SO',
     'SRB': 'RS',
@@ -204,6 +204,113 @@ IOC_TO_ISO = {
     'ZAM': 'ZM',
     'ZIM': 'ZW',
 }
+IOC_HISTORICAL_TO_ISO = {
+    'AGR': 'DZ',
+    'AGL': 'DZ',
+    'BAD': 'BB',
+    'DAY': 'BJ',
+    'DAH': 'BJ',
+    'BSH': 'BA',
+    'HBR': 'BZ',
+    'VOL': 'BF',
+    'AFC': 'CF',
+    'CAB': 'KH',
+    'KHM': 'KH',
+    'CHD': 'TD',
+    'CIL': 'CL',
+    'PRC': 'CN',
+    'IVC': 'CI',
+    'CML': 'CI',
+    'COK': 'CD',
+    'ZAI': 'CD',
+    'COS': 'CR',
+    'TCH': 'CZ',
+    'DAN': 'DK',
+    'DIN': 'DK',
+    'RAU': 'EG',  # Used 1960, 1968 (also used by Syria in 1960)
+    'UAR': 'EG',
+    'SAL': 'SV',
+    'SPA': 'ES',
+    'ETI': 'ET',
+    'FIG': 'FJ',
+    'GRB': 'GB',
+    'GBI': 'GB',
+    'ALL': 'DE',
+    'ALE': 'DE',
+    'GUT': 'GT',
+    'GUA': 'GY',
+    'GUI': 'GY',
+    'HOK': 'HK',
+    'UNG': 'HU',
+    'INS': 'ID',
+    'IRN': 'IR',
+    'IRA': 'IR',
+    'IRK': 'IQ',
+    'ICE': 'IS',
+    'ISL': 'IL',
+    'GIA': 'JP',
+    'JAP': 'JP',
+    'COR': 'KR',
+    'ARS': 'SA',
+    'SAU': 'SA',
+    'LYA': 'LY',
+    'LBY': 'LY',
+    'LEB': 'LB',  # Used from 1960-1964
+    'LIB': 'LB',  # Used from 1964-2016
+    'LIC': 'LI',
+    'LIT': 'LT',
+    'MAG': 'MG',
+    'MRC': 'MA',
+    'MAL': 'MY',
+    'MLD': 'MD',
+    'MOD': 'MN',
+    'MAT': 'MT',
+    'BIR': 'MM',
+    'BUR': 'MM',
+    'NGC': 'NI',
+    'NIC': 'NI',
+    'OLA': 'NL',
+    'NET': 'NL',
+    'NLD': 'NL',
+    'HOL': 'NL',
+    'NIG': 'NG',
+    'NGA': 'NG',
+    'NGR': 'NE',
+    'NZE': 'NZ',
+    'FIL': 'PH',
+    'NGY': 'PG',
+    'NGU': 'PG',
+    'NKO': 'KP',
+    'CDN': 'KP',
+    'PRI': 'PR',
+    'PRO': 'PR',
+    'ROM': 'RO',
+    'RUM': 'RO',
+    'SAF': 'ZA',
+    'SGL': 'SN',
+    'SIN': 'SG',  # Used from 1959-2016
+    'SLA': 'SL',
+    'SMA': 'SM',
+    'CEY': 'LK',
+    'CEI': 'LK',
+    'SVI': 'CH',
+    'SVE': 'SE',
+    'SUE': 'SE',
+    'SIR': 'SY',
+    'TON': 'TO',
+    'IOA': 'TL',
+    'RCF': 'TW',
+    'TWN': 'TW',
+    'ROC': 'TW',
+    'TRT': 'TT',
+    'URG': 'UY',
+    'SUA': 'US',
+    'EUA': 'US',
+    'VET': 'VN',
+    'VNM': 'VN',
+    'NRH': 'ZM',
+    'RHO': 'ZW',
+}
 
 ISO_TO_IOC = dict((iso, ioc) for ioc, iso in IOC_TO_ISO.items())
 
