@@ -6,13 +6,13 @@ from django.utils.encoding import force_text
 from django_countries import countries
 
 
-class CountryField(serializers.Field):
+class CountryField(serializers.ChoiceField):
 
     def __init__(self, *args, **kwargs):
         self.country_dict = kwargs.pop('country_dict', None)
-        countries_class = kwargs.pop('countries', None)
-        self.countries = countries_class() if countries_class else countries
-        super(CountryField, self).__init__(*args, **kwargs)
+        field_countries = kwargs.pop('countries', None)
+        self.countries = field_countries if field_countries else countries
+        super(CountryField, self).__init__(self.countries, *args, **kwargs)
 
     def to_representation(self, obj):
         code = self.countries.alpha2(obj)
@@ -25,4 +25,9 @@ class CountryField(serializers.Field):
     def to_internal_value(self, data):
         if isinstance(data, dict):
             data = data.get('code')
-        return self.countries.alpha2(data)
+        country = self.countries.alpha2(data)
+        if data and not country:
+            country = self.countries.by_name(force_text(data))
+            if not country:
+                self.fail('invalid_choice', input=data)
+        return country
