@@ -17,8 +17,8 @@ class AllowNullForm(forms.ModelForm):
         fields = ['country']
 
 
-class LegacyForm(forms.ModelForm):
+class MultiCountryForm(forms.ModelForm):
 
     class Meta:
-        model = models.Legacy
-        fields = ['default', 'default_callable']
+        model = models.MultiCountry
+        fields = ['countries']
